@@ -36,11 +36,9 @@ set -x
 
 cd "$base"
 autoreconf --install --force
-./configure --enable-external-tests
+./configure --enable-sanitize --enable-external-tests --enable-werror
 $MAKE $PARALLEL_MAKE
-if [ "x$label" != "xFreeBSD_amd64" ]; then
-    $MAKE check || cat-testlogs.sh
-    $MAKE distcheck || cat-testlogs.sh
-fi
+$MAKE check || cat-testlogs.sh
+$MAKE distcheck || cat-testlogs.sh
 
 osmo-clean-workspace.sh
