@@ -26,13 +26,13 @@
 #include <osmocom/core/logging.h>
 #include <osmocom/core/application.h>
 #include <osmocom/gsm/gsup.h>
-#include <osmocom/gsm/apn.h>
 #include <osmocom/gsm/gsm48_ie.h>
 #include <osmocom/vty/vty.h>
 #include <osmocom/vty/command.h>
 #include <osmocom/vty/telnet_interface.h>
 #include <osmocom/vty/ports.h>
 #include <osmocom/ctrl/control_vty.h>
+#include <osmocom/gsm/apn.h>
 
 #include "db.h"
 #include "hlr.h"
@@ -46,6 +46,93 @@
 
 static struct hlr *g_hlr;
 
+/* Trigger 'Insert Subscriber Data' messages to all connected GSUP clients.
+ *
+ * FIXME: In order to support large-scale networks this function should skip
+ * VLRs/SGSNs which do not currently serve the subscriber.
+ *
+ * \param[in] subscr  A subscriber we have new data to send for.
+ */
+void
+osmo_hlr_subscriber_update_notify(struct hlr_subscriber *subscr)
+{
+        struct osmo_gsup_conn *co;
+
+	if (g_hlr->gs == NULL)
+		return;
+
+	llist_for_each_entry(co, &g_hlr->gs->clients, list) {
+		struct osmo_gsup_message gsup = {
+			.message_type = OSMO_GSUP_MSGT_INSERT_DATA_REQUEST
+		};
+		uint8_t *peer;
+		int peer_len;
+		uint8_t msisdn_enc[43]; /* TODO use constant; TS 24.008 10.5.4.7 */
+		uint8_t apn[APN_MAXLEN];
+		int len;
+		struct msgb *msg_out;
+
+		peer_len = osmo_gsup_conn_ccm_get(co, &peer, IPAC_IDTAG_SERNR);
+		if (peer_len < 0) {
+			LOGP(DMAIN, LOGL_ERROR,
+			       "IMSI='%s': Cannot notify GSUP client, cannot get peer name "
+			       "for %s:%u\n", subscr->imsi,
+			       co && co->conn && co->conn->server? co->conn->server->addr : "unset",
+			       co && co->conn && co->conn->server? co->conn->server->port : 0);
+			continue;
+		}
+
+		osmo_strlcpy(gsup.imsi, subscr->imsi, GSM23003_IMSI_MAX_DIGITS + 1);
+
+		len = gsm48_encode_bcd_number(msisdn_enc, sizeof(msisdn_enc), 0, subscr->msisdn);
+		if (len < 1) {
+			LOGP(DMAIN, LOGL_ERROR, "%s: Error: cannot encode MSISDN '%s'\n",
+			     subscr->imsi, subscr->msisdn);
+			continue;
+		}
+		gsup.msisdn_enc = msisdn_enc;
+		gsup.msisdn_enc_len = len;
+
+		if (co->supports_ps) {
+			gsup.cn_domain = OSMO_GSUP_CN_DOMAIN_PS;
+
+			/* FIXME: PDP infos - use more fine-grained access control
+			   instead of wildcard APN */
+			if (osmo_gsup_configure_wildcard_apn(&gsup, apn, sizeof(apn))) {
+				LOGP(DMAIN, LOGL_ERROR, "%s: Error: cannot encode wildcard APN\n",
+				     subscr->imsi);
+				continue;
+			}
+		} else if (co->supports_cs) {
+			gsup.cn_domain = OSMO_GSUP_CN_DOMAIN_CS;
+		} else {
+			/* We have not yet received a location update from this subscriber .*/
+			continue;
+		}
+
+		/* Send ISD to MSC/SGSN */
+		msg_out = msgb_alloc_headroom(1024+16, 16, "GSUP ISD UPDATE");
+		if (msg_out == NULL) {
+			LOGP(DMAIN, LOGL_ERROR,
+			       "IMSI='%s': Cannot notify GSUP client; could not allocate msg buffer "
+			       "for %s:%u\n", subscr->imsi,
+			       co && co->conn && co->conn->server? co->conn->server->addr : "unset",
+			       co && co->conn && co->conn->server? co->conn->server->port : 0);
+			continue;
+		}
+
+		osmo_gsup_encode(msg_out, &gsup);
+		if (osmo_gsup_addr_send(g_hlr->gs, peer, peer_len, msg_out) < 0) {
+			LOGP(DMAIN, LOGL_ERROR,
+			       "IMSI='%s': Cannot notify GSUP client; send operation failed "
+			       "for %s:%u\n", subscr->imsi,
+			       co && co->conn && co->conn->server? co->conn->server->addr : "unset",
+			       co && co->conn && co->conn->server? co->conn->server->port : 0);
+			continue;
+		}
+	}
+}
+
 /***********************************************************************
  * Send Auth Info handling
  ***********************************************************************/
@@ -67,12 +154,27 @@ static int rx_send_auth_info(struct osmo_gsup_conn *conn,
 			gsup_out.auth_vectors,
 			ARRAY_SIZE(gsup_out.auth_vectors),
 			gsup->rand, gsup->auts);
-	if (rc < 0) {
+	if (rc <= 0) {
 		gsup_out.message_type = OSMO_GSUP_MSGT_SEND_AUTH_INFO_ERROR;
-		gsup_out.cause = GMM_CAUSE_NET_FAIL;
-	} else if (rc == 0) {
-		gsup_out.message_type = OSMO_GSUP_MSGT_SEND_AUTH_INFO_ERROR;
-		gsup_out.cause = GMM_CAUSE_IMSI_UNKNOWN;
+		switch (rc) {
+		case 0:
+			/* 0 means "0 tuples generated", which shouldn't happen.
+			 * Treat the same as "no auth data". */
+		case -ENOKEY:
+			LOGP(DAUC, LOGL_NOTICE, "%s: IMSI known, but has no auth data;"
+			     " Returning slightly inaccurate cause 'IMSI Unknown' via GSUP\n",
+			     gsup->imsi);
+			gsup_out.cause = GMM_CAUSE_IMSI_UNKNOWN;
+			break;
+		case -ENOENT:
+			LOGP(DAUC, LOGL_NOTICE, "%s: IMSI not known\n", gsup->imsi);
+			gsup_out.cause = GMM_CAUSE_IMSI_UNKNOWN;
+			break;
+		default:
+			LOGP(DAUC, LOGL_ERROR, "%s: failure to look up IMSI in db\n", gsup->imsi);
+			gsup_out.cause = GMM_CAUSE_NET_FAIL;
+			break;
+		}
 	} else {
 		gsup_out.message_type = OSMO_GSUP_MSGT_SEND_AUTH_INFO_RESULT;
 		gsup_out.num_auth_vectors = rc;
@@ -155,8 +257,19 @@ static int rx_upd_loc_req(struct osmo_gsup_conn *conn,
 
 	lu_op_statechg(luop, LU_S_LU_RECEIVED);
 
-	if (gsup->cn_domain == OSMO_GSUP_CN_DOMAIN_PS)
+	if (gsup->cn_domain == OSMO_GSUP_CN_DOMAIN_CS)
+		conn->supports_cs = true;
+	if (gsup->cn_domain == OSMO_GSUP_CN_DOMAIN_PS) {
+		conn->supports_ps = true;
 		luop->is_ps = true;
+	} else {
+		/* The client didn't send a CN_DOMAIN IE; assume packet-switched in
+		 * accordance with the GSUP spec in osmo-hlr's user manual (section
+		 * 11.6.15 "CN Domain" says "if no CN Domain IE is present within
+		 * a request, the PS Domain is assumed." */
+		conn->supports_ps = true;
+		luop->is_ps = true;
+	}
 	llist_add(&luop->list, &g_lu_ops);
 
 	/* Roughly follwing "Process Update_Location_HLR" of TS 09.02 */
@@ -164,7 +277,7 @@ static int rx_upd_loc_req(struct osmo_gsup_conn *conn,
 	/* check if subscriber is known at all */
 	if (!lu_op_fill_subscr(luop, g_hlr->dbc, gsup->imsi)) {
 		/* Send Error back: Subscriber Unknown in HLR */
-		strcpy(luop->subscr.imsi, gsup->imsi);
+		osmo_strlcpy(luop->subscr.imsi, gsup->imsi, sizeof(luop->subscr.imsi));
 		lu_op_tx_error(luop, GMM_CAUSE_IMSI_UNKNOWN);
 		return 0;
 	}
@@ -223,9 +336,9 @@ static int rx_purge_ms_req(struct osmo_gsup_conn *conn,
 	/* Perform the actual update of the DB */
 	rc = db_subscr_purge(g_hlr->dbc, gsup->imsi, true, is_ps);
 
-	if (rc == 1)
+	if (rc == 0)
 		gsup_reply.message_type = OSMO_GSUP_MSGT_PURGE_MS_RESULT;
-	else if (rc == 0) {
+	else if (rc == -ENOENT) {
 		gsup_reply.message_type = OSMO_GSUP_MSGT_PURGE_MS_ERROR;
 		gsup_reply.cause = GMM_CAUSE_IMSI_UNKNOWN;
 	} else {
@@ -424,10 +537,11 @@ int main(int argc, char **argv)
 
 	hlr_ctx = talloc_named_const(NULL, 1, "OsmoHLR");
 	msgb_talloc_ctx_init(hlr_ctx, 0);
+	vty_info.tall_ctx = hlr_ctx;
 
 	g_hlr = talloc_zero(hlr_ctx, struct hlr);
 
-	rc = osmo_init_logging(&hlr_log_info);
+	rc = osmo_init_logging2(hlr_ctx, &hlr_log_info);
 	if (rc < 0) {
 		fprintf(stderr, "Error initializing logging\n");
 		exit(1);
@@ -460,7 +574,7 @@ int main(int argc, char **argv)
 		exit(1);
 	}
 
-	g_hlr->dbc = db_open(hlr_ctx, cmdline_opts.db_file);
+	g_hlr->dbc = db_open(hlr_ctx, cmdline_opts.db_file, true);
 	if (!g_hlr->dbc) {
 		LOGP(DMAIN, LOGL_FATAL, "Error opening database\n");
 		exit(1);
