@@ -5,19 +5,19 @@ const struct log_info_cat hlr_log_info_cat[] = {
 	[DMAIN] = {
 		.name = "DMAIN",
 		.description = "Main Program",
-		.enabled = 1, .loglevel = LOGL_DEBUG,
+		.enabled = 1, .loglevel = LOGL_NOTICE,
 	},
 	[DDB] = {
 		.name = "DDB",
 		.description = "Database Layer",
 		.color = "\033[1;31m",
-		.enabled = 1, .loglevel = LOGL_DEBUG,
+		.enabled = 1, .loglevel = LOGL_NOTICE,
 	},
 	[DAUC] = {
 		.name = "DAUC",
 		.description = "Authentication Center",
 		.color = "\033[1;33m",
-		.enabled = 1, .loglevel = LOGL_DEBUG,
+		.enabled = 1, .loglevel = LOGL_NOTICE,
 	},
 };
 
