@@ -108,8 +108,7 @@ struct lu_operation *lu_op_alloc(struct osmo_gsup_server *srv)
 	luop = talloc_zero(srv, struct lu_operation);
 	OSMO_ASSERT(luop);
 	luop->gsup_server = srv;
-	luop->timer.cb = lu_op_timer_cb;
-	luop->timer.data = luop;
+	osmo_timer_setup(&luop->timer, lu_op_timer_cb, luop);
 
 	return luop;
 }
@@ -119,6 +118,10 @@ void lu_op_free(struct lu_operation *luop)
 	/* Only attempt to remove when it was ever added to a list. */
 	if (luop->list.next)
 		llist_del(&luop->list);
+
+	/* Delete timer just in case it is still pending. */
+	osmo_timer_del(&luop->timer);
+
 	talloc_free(luop);
 }
 
@@ -162,23 +165,6 @@ void lu_op_statechg(struct lu_operation *luop, enum lu_state new_state)
 	luop->state = new_state;
 }
 
-/* Send a msgb to a given address using routing */
-int osmo_gsup_addr_send(struct osmo_gsup_server *gs,
-			const uint8_t *addr, size_t addrlen,
-			struct msgb *msg)
-{
-	struct osmo_gsup_conn *conn;
-
-	conn = gsup_route_find(gs, addr, addrlen);
-	if (!conn) {
-		DEBUGP(DMAIN, "Cannot find route for addr %s\n", addr);
-		msgb_free(msg);
-		return -ENODEV;
-	}
-
-	return osmo_gsup_conn_send(conn, msg);
-}
-
 /*! Transmit UPD_LOC_ERROR and destroy lu_operation */
 void lu_op_tx_error(struct lu_operation *luop, enum gsm48_gmm_cause cause)
 {
@@ -230,8 +216,8 @@ void lu_op_tx_cancel_old(struct lu_operation *luop)
 void lu_op_tx_insert_subscr_data(struct lu_operation *luop)
 {
 	struct osmo_gsup_message gsup;
-	uint8_t apn[APN_MAXLEN];
 	uint8_t msisdn_enc[43]; /* TODO use constant; TS 24.008 10.5.4.7 */
+	uint8_t apn[APN_MAXLEN];
 	int l;
 
 	OSMO_ASSERT(luop->state == LU_S_LU_RECEIVED ||
@@ -251,20 +237,16 @@ void lu_op_tx_insert_subscr_data(struct lu_operation *luop)
 	gsup.msisdn_enc = msisdn_enc;
 	gsup.msisdn_enc_len = l;
 
-	/* FIXME: deal with encoding the following data */
-	gsup.hlr_enc;
+	#pragma message "FIXME: deal with encoding the following data: gsup.hlr_enc"
 
 	if (luop->is_ps) {
 		/* FIXME: PDP infos - use more fine-grained access control
 		   instead of wildcard APN */
-		l = osmo_apn_from_str(apn, sizeof(apn), "*");
-		if (l > 0) {
-			gsup.pdp_infos[0].apn_enc = apn;
-			gsup.pdp_infos[0].apn_enc_len = l;
-			gsup.pdp_infos[0].have_info = 1;
-			gsup.num_pdp_infos = 1;
-			/* FIXME: use real value: */
-			gsup.pdp_infos[0].context_id = 1;
+		if (osmo_gsup_configure_wildcard_apn(&gsup, apn, sizeof(apn))) {
+			LOGP(DMAIN, LOGL_ERROR, "%s: Error: cannot encode wildcard APN\n",
+			     luop->subscr.imsi);
+			lu_op_tx_error(luop, GMM_CAUSE_PROTO_ERR_UNSPEC);
+			return;
 		}
 	}
 
